function Contextual_(fnCfg) 

% This Function is used to generate semantic representation based on 
% contextual Map Algorithrim (see Kohonen, 2001, Self-Organizing Maps )  
% Copyright (C) 2009 Xiaowei Zhao 

if nargin < 1
  disp(' ');
  disp(' Contextual_    Generating semantic representation');
  disp(' based on Contextual Map Algorithrim. It uses the transitional probabilities  ');
  disp(' between neighoring words, which is obtained by the function of Coocuur_. ');
  disp(' There are two resulting files, one is in matlab (.mat) format,');
  disp(' the other one (.repr) is in SOMPAK format');
  disp(' All simulation parameters are read from the configuration file.');
  disp(' ' );
  disp('  Usage: Contextual_ fnCfg');
  disp(' ');
  return;
end

par = context_read_par(fnCfg);
fprintf(1,'Reading parameters from %s...\n',fnCfg);
par

lex = read_strlist([par.datadir par.fnLex]);
load([par.datadir par.fnMat]);

maxWords = size(probL,1);
testWords = par.lex(end);

if length(par.lex) > 1
  fprintf(1,'Multiple vocabulary sizes specified.\n');
else 
  fprintf(1,'Lexicon: %d words\n',par.lex); 
end

if length(lex) < testWords , error('Not enough labels available.'); end
if length(lex) > testWords, fprintf(1,'Only the representations of the first %d... words are calculated\n', testWords); end
if ~isempty(lex), fprintf(1,'Labels will be attached to word reps.\n'); end

if testWords > 3500
    fprintf(1,'Sparse matrix is used due to the huge lexicon size (above 3500) \n');
    probL= probL(1:testWords,1:testWords);% full(probL(1:testWords,1:testWords))
    probR= probR(1:testWords,1:testWords);% full(probR(1:testWords,1:testWords))
else
    probL= full(probL(1:testWords,1:testWords));
    probR= full(probR(1:testWords,1:testWords));
end

Lfreq=sum(probL,2);
Rfreq=sum(probR,2);

    testWords = par.lex
    
   if strmatch(par.Gaussian, 'ON', 'exact')
    fprintf(1,'Gaussian distribution is used!\n');
    init_v = randn(testWords, par.veclength);
   else
    fprintf(1,'Random numbers uniformly distributed between -1 and 1 is used!\n');
    init_v = rand(testWords, par.veclength)*2-1;
   end
    vMag = sqrt(sum(init_v.^2,2));
    init_v = init_v./repmat(vMag,1,par.veclength);

    rep = zeros(testWords, par.veclength*2);

    for i=1: testWords
      if ~rem(i,100) fprintf(1,'%7d',i); end
      if ~rem(i,1000) fprintf(1,'\n'); end
     if Lfreq(i)~= 0, rep(i, 1:par.veclength) = sum(repmat(probL(i,:)', 1, par.veclength).*init_v)/Lfreq(i); end
     if Rfreq(i)~= 0, rep(i, par.veclength+1:par.veclength*2) = sum(repmat(probR(i,:)', 1, par.veclength).*init_v)/Rfreq(i); end
    end

    
    fn = [par.datadir par.fnOut '.' num2str(testWords) '.repr'];

    lex(Lfreq == 0 & Rfreq == 0) % show the words that do not have any known neighboring words 
    temp=lex(Lfreq == 0 & Rfreq == 0);
    if ~isempty(temp) save ([par.datadir par.fnOut '.' num2str(testWords) '.norepwords.mat'],'temp'); end  
    
    fprintf(1,'There are %d words without known meighbors\n',size(temp,1));
    
    % add labels if available
    if ~isempty(lex), repr.lab = lex(~(Lfreq == 0 & Rfreq == 0)); else repr.lab = []; end
    repr.dat = rep(~(Lfreq == 0 & Rfreq == 0),:);

    % save file
    fprintf(1,'Saving output to %s...',fn);
 
        repr.dat = repr.dat;
        write_data(repr.dat,repr.lab,fn,1); 
        
        fn = [par.datadir par.fnOut '.' num2str(testWords) '.mat']
        save(fn,'repr');






