% This routine is used to test the performance of the semantic
% representation based on contexual map algorithrim. 
% A batch Self-organizing Map is constructed and the semantic representations 
% of each word is sent into the network as input, after training, each word's BMU
% is labeled with the word on the map. And a U-matrix figure is further drawn.

% Users must have SOMToolBox installed on their computer to run this routine.
% SOMToolBox can be obtained from
% http://www.cis.hut.fi/projects/somtoolbox/

% Users can also use som_gui function in the ToolBox to load the '.repr' file 
% created by Contexual_ function, then set up the training parameters 
% e.g. map size; initial radius; # of training epochs ....   

% Below is an example with a 50x60 map, using hexagon topological structure, 
% initial radius as 25, trained for 200 epochs  

% Copyright (C) 2009 Xiaowei Zhao 

% load representation from the mat file created by Contextual_ function
% assume it is under the folder of data 
load 'Grimm_.2443.mat';   
repr.dat=repr.dat(1:300,:);
repr.lab=repr.lab(1:300,:);
sData = som_data_struct(repr.dat,'labels',repr.lab,'name','ContexualMap');
sMap  = som_randinit(sData, 'msize', [50 60], 'hexa');
 

r = (1-[1:200]/200); 
sMap = som_batchtrain(sMap,sData,'tracking',2,...
'trainlen',200,'radius',24*r+1);

% Though not an indispensable step, a fine tuning stage with a constant
% radius paramenter (here is 1 -- the smallest radius in the previous
% stage) may be included to improve the clustering performance 
% of the map (as in the three lines shown below)   

%r=ones(100);
%sMap = som_batchtrain(sMap,sData,'tracking',2,...
%'trainlen',100,'radius',r);

sMap = som_label(sMap,'clear','all');
sMap = som_label(sMap,'add',som_bmus(sMap,sData),sData.labels);
som_show(sMap,'empty','Labels')
som_show_add('label',sMap,'Textsize',9,'TextColor','b')

figure;
%colormap(1-gray);
som_show(sMap,'umat','all','bar','none') % show u-matrix



