function out = normalize(data,lnorm)

% Normalizes the data according to l-norm.
% If data is a matrix, rows are normalized.
%
% out = normalize(data,lnorm)
%
%   data - vector or matrix
%   lnorm = L-norm (1 or 2)

if (lnorm ~= 1 & lnorm ~= 2), error('lnorm must be 1 or 2\n'); end
if min(size(data)) == 1
  n = norm(data,lnorm);
  if n > 0, out = data/n; else out = 0; end
  return;
else
  for i=1:size(data,1)
    n = norm(data(i,:),lnorm);
    if n > 0, out(i,:) = data(i,:)/n; else out(i,:) = 0; end
  end
end
