function idx = nummatch(item,list,mode)

% Returns the corresponding index (or row of indices) of the number found 
% in the list, otherwise returns 0. List can be 2D and rows are compared.
%
% idx = nummatch(item,list,mode)
%
% item - item to be found
% list - list of items
% mode - if mode==1, only first match returned, mode==2 returns all matches,
%        default is mode==1
% idx  - index (list of indices) of the found item in the list; if not found,
%        [] is returned

error(nargchk(2,3,nargin));

if isempty(list), idx = 0; return; end
if nargin == 2, mode = 1; end

idx = [];
switch min(size(list))
case 1,                  % 1D vector
  for k=1:length(list)
    if list(k) == item,
      idx = [idx k]; 
      if mode == 1, return; end
    end
  end
otherwise,               % 2D matrix 
  if size(list,2) ~= length(item), error('dimension mismatch'); end
  for k=1:size(list,1)
    if (list(k,:) == item), 
      idx = [idx k]; 
      if mode == 1, return; end
    end
  end
end
