function write_data(data, labels, filename, dataFirst, spec, nodim)

% write_data(data, labels, filename, dataFirst, spec)
%
%  data        matrix data to be written
%  labels      data labels, if known
%  filename    (string) output filename
%  dataFirst   if 1, data go first, if 0 labels go first
%  spec        data format specification (default is '%f ')
%  nodim       if specified, data dimension will not be written on line 1

error(nargchk(4, 6, nargin));

[samples dim] = size(data);

fid = fopen(filename, 'w');
if fid < 0
  if nargout > 0, f = 0; return; end;
  error(['Cannot open file ' filename]);
end

if nargin == 5 | ~exist('nodim') | nodim ~= 1
  fprintf(fid, '%d\n', dim);        % write dimension
end

if nargin >= 5,
  if exist('spec'), fmt = spec; end
  if isempty(findstr(fmt,' ')), fmt = [fmt ' ']; end
else fmt = '%f ';
end

for i = 1:samples

  if ~rem(i, 1000) fprintf(1,'%7d', i); end
  if ~rem(i,10000) fprintf(1,'\n'); end
  
  if dataFirst
    fprintf(fid, '%s', sprintf(fmt, data(i,:)));
    if ~isempty(labels), fprintf(fid, '%s ', char(labels{i})); end
  else
    if ~isempty(labels), fprintf(fid, '%s ', char(labels{i})); end
    fprintf(fid, '%s', sprintf(fmt, data(i,:)));
  end
  fprintf(fid, '\n');
end
fprintf(1,'%6d', samples); 

% close file
if fclose(fid), error(['Cannot close file ' filename]);
else fprintf(1,' lines written ok\n'); end
